@@ -174,7 +174,7 @@ class PEAR_DependencyDB
             $this->rebuildDB();
         }
 
-        if ($depdb['_version']{0} > $this->_version{0}) {
+        if ($depdb['_version'][0] > $this->_version[0]) {
             return PEAR::raiseError('Dependency database is version ' .
                 $depdb['_version'] . ', and we are version ' .
                 $this->_version . ', cannot continue');
@@ -216,9 +216,11 @@ class PEAR_DependencyDB
         if (is_object($pkg)) {
             $channel = strtolower($pkg->getChannel());
             $package = strtolower($pkg->getPackage());
-        } else {
+        } else if (is_array($pkg)) {
             $channel = strtolower($pkg['channel']);
             $package = strtolower($pkg['package']);
+        } else {
+            return false;
         }
 
         $depend = $this->getDependentPackages($pkg);
@@ -499,8 +501,13 @@ class PEAR_DependencyDB
         }
 
         if (!is_resource($this->_lockFp)) {
+            $last_errormsg = '';
+            $last_error = error_get_last();
+            if (!empty($last_error['message'])) {
+                $last_errormsg = $last_error['message'];
+            }
             return PEAR::raiseError("could not create Dependency lock file" .
-                                     (isset($php_errormsg) ? ": " . $php_errormsg : ""));
+                                     (isset($last_errormsg) ? ": " . $last_errormsg : ""));
         }
 
         if (!(int)flock($this->_lockFp, $mode)) {
@@ -553,7 +560,7 @@ class PEAR_DependencyDB
 
         clearstatcache();
         fclose($fp);
-        $data = unserialize(file_get_contents($this->_depdb));
+        $data = @unserialize(file_get_contents($this->_depdb));
         $this->_cache = $data;
         return $data;
     }
