@@ -88,7 +88,11 @@ class PEAR_RunTest
         if (!defined('E_STRICT')) {
             define('E_STRICT', 0);
         }
-        $this->ini_overwrites[] = 'error_reporting=' . (E_ALL & ~(E_DEPRECATED | E_STRICT));
+        $excluded_error_reporting = E_DEPRECATED;
+        if (!defined('PHP_VERSION_ID') || PHP_VERSION_ID < 80400) {
+            $excluded_error_reporting |= E_STRICT;
+        }
+        $this->ini_overwrites[] = 'error_reporting=' . (E_ALL & ~$excluded_error_reporting);
         if (is_null($logger)) {
             require_once 'PEAR/Common.php';
             $logger = new PEAR_Common;
@@ -129,7 +133,8 @@ class PEAR_RunTest
         while (true) {
             /* hide errors from interrupted syscalls */
             $r = $pipes;
-            $e = $w = null;
+            unset($r[0]);
+            $e = $w = [];
             $n = @stream_select($r, $w, $e, 60);
 
             if ($n === 0) {
@@ -511,6 +516,7 @@ class PEAR_RunTest
                     $wanted_re = preg_quote($wanted_re, '/');
                     // Stick to basics
                     $wanted_re = str_replace("%s", ".+?", $wanted_re); //not greedy
+                    $wanted_re = str_replace("%S", ".*?", $wanted_re); //not greedy
                     $wanted_re = str_replace("%i", "[+\-]?[0-9]+", $wanted_re);
                     $wanted_re = str_replace("%d", "[0-9]+", $wanted_re);
                     $wanted_re = str_replace("%x", "[0-9a-fA-F]+", $wanted_re);
